@@ -2,4 +2,6 @@
 from .memory import MemoryRepo
 from .mongo import MongoRepo
 from .sqlalchemy import SQLRepo
-from .rest import RESTRepo
\ No newline at end of file
+from .rest import RESTRepo
+from .csv import CSVFileRepo
+from .json import JSONDirectoryRepo
\ No newline at end of file
